<!--

#################################################
### THIS FILE WAS AUTOGENERATED! DO NOT EDIT! ###
#################################################
# file to edit: index.ipynb
# command to build the docs after a change: nbdev_build_docs

-->

# Hello_fastai

> Trying new nbdev tool

<div class="codecell" markdown="1">
<div class="input_area" markdown="1">

```python
%load_ext autoreload
%autoreload 2
```

</div>
<div class="output_area" markdown="1">

    The autoreload extension is already loaded. To reload it, use:
      %reload_ext autoreload


</div>

</div>

This file will become your README and also the index of your documentation.

## Install

`pip install Hello_fastai`

## How to use


say_hello("world")
Hello world!
<div class="codecell" markdown="1">
<div class="input_area" markdown="1">

```python
1+1
```

</div>
<div class="output_area" markdown="1">




    2



</div>

</div>
<div class="codecell" markdown="1">
<div class="input_area" markdown="1">

```python
class HelloSayer:
    "Say Hello to `to` using `say_hello`"
    def __init__(self,to): self.to = to      
    def say(self):
        "Do the saying"
        return say_hello(self.to)
        

```

</div>

</div>
<div class="codecell" markdown="1">
<div class="input_area" markdown="1">

```python
o = HelloSayer("Vanh")
o.say()
```

</div>
<div class="output_area" markdown="1">

    Hello Vanh!


</div>

</div>
<div class="codecell" markdown="1">
<div class="input_area" markdown="1">

```python
#show_doc(HelloSayer.say)
```

</div>

</div>
<div class="codecell" markdown="1">
<div class="input_area" markdown="1">

```python
from nbdev.export import notebook2script
notebook2script()
```

</div>
<div class="output_area" markdown="1">

    Converted 00_core.ipynb.
    Converted index.ipynb.


</div>

</div>
